@@ -1,6 +1,6 @@
 from pkg_resources import get_distribution, DistributionNotFound
 
-from pynetbox.core.query import RequestError
+from pynetbox.core.query import RequestError, AllocationError, ContentError
 from pynetbox.api import Api as api
 
 try:
